@@ -10,6 +10,8 @@ Connpy is a connection manager that allows you to store nodes to connect them fa
       information.
     - Nodes can be stored on @folder or @subfolder@folder to organize your 
       devices. Then can be referenced using node@subfolder@folder or node@folder
+    - If you have too many nodes. Get completion script using: conn config 
+      --completion, or use fzf installing pyfzf and running conn config --fzf true
     - Much more!
 
 ### Usage
@@ -24,12 +26,12 @@ positional arguments:
                  Show all available connections globaly or in specified path
 Options:
   -h, --help         show this help message and exit
+  -v, --version      Show version
   -a, --add          Add new node[@subfolder][@folder] or [@subfolder]@folder
   -r, --del, --rm    Delete node[@subfolder][@folder] or [@subfolder]@folder
   -e, --mod, --edit  Modify node[@subfolder][@folder]
   -s, --show         Show node[@subfolder][@folder]
   -d, --debug        Display all conections steps
-  -v, --version      Show version
 
 Commands:
   profile        Manage profiles
@@ -131,4 +133,5 @@ __all__ = ["node", "nodes", "configfile", "connapp"]
 __author__ = "Federico Luzzi"
 __pdoc__ = {
     'core': False,
+    'completion': False,
 }
